meson_python: Meson Python build backend (PEP 517)
==================================================

Description
-----------

Meson Python build backend (PEP 517)

License
-------

Upstream Contact
----------------

https://pypi.org/project/meson-python/

